within ProjetTAG.Composants;

model CompressorCombiTable "Extension du compresseur de base, utilisant des tables pour les caractéristiques reliant taux de compression, débit, vitesse de rotation et rendement isentropique"
// Les connecteurs : une entrée, une sortie fluides; une entrée, une sortie mécaniques de la librairie standard Modelica
  Connectors.FluidPort inlet annotation(
    Placement(visible = true, transformation(origin = {-90, 58}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-90, 70}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Connectors.FluidPort outlet annotation(
    Placement(visible = true, transformation(origin = {92, -40}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {90, -30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Mechanics.Rotational.Interfaces.Flange_a flange_a annotation(
    Placement(visible = true, transformation(origin = {-88, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {-90, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Mechanics.Rotational.Interfaces.Flange_b flange_b annotation(
    Placement(visible = true, transformation(origin = {88, 2}, extent = {{-10, -10}, {10, 10}}, rotation = 0), iconTransformation(origin = {90, 0}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
// Les variables
  SI.Angle phi "shaft rotation angle";
  SI.Torque tau "net torque acting on the turbine";
  SI.AngularVelocity omega "shaft angular velocity";
  SI.MassFlowRate qm "Mass flow rate";
  SI.MassFlowRate qm_corr "Corrected Mass flow rate";
  SI.SpecificEnthalpy hin "Inlet enthalpy";
  SI.SpecificEnthalpy hout "Outlet enthalpy";
  SI.Temperature Tin "Inlet temperature";
  SI.Temperature Tout "Outlet temperature";
  SI.Temperature Tis "isentropic Outlet temperature";
  SI.PerUnit PR "Le taux de compression";
  Real N "Rapport (en %) de la vitesse angulaire à la vitesse angulaire de référence";
  Real beta "variable d'interpolation dans la table";
  SI.PerUnit eta_is "Rendement isentropique";//devient ici variable
  SI.Power Pcomp "Puissance mécanique";

  Modelica.Blocks.Tables.CombiTable2Ds table_PR(table = tablePR) annotation(
    Placement(visible = true, transformation(origin = {2, -70}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Blocks.Tables.CombiTable2Ds table_eta(table = tableEtaC) annotation(
    Placement(visible = true, transformation(origin = {2, -30}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Blocks.Tables.CombiTable2Ds table_qm(table = tableQm) annotation(
    Placement(visible = true, transformation(origin = {2, 10}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));

// Les paramètres
  parameter SI.Temperature T0=293.15;
  parameter SI.Pressure P0=1e5;
  parameter SI.AngularVelocity omega0=1500*Modelica.Constants.pi/30;

// Tables à fournir à partir des champs numérisés
  parameter Real tableQm[11, 5] = [1];
  parameter Real tablePR[11, 5] = [1];
  parameter Real tableEtaC[11, 5] = [1];
  
equation

// Lecture des valeurs en entrée fluide
  qm = inlet.m_flow;
  hin = inStream(inlet.h_outflow);
  outlet.h_outflow = hout;
// Mechanical boundary conditions
  flange_a.phi = phi;
  flange_b.phi = phi;
  flange_a.tau + flange_b.tau = tau;
  der(phi) = omega;
  Pcomp = tau * omega;
//Reverse flow equation : ask the teacher for explanations
  inlet.h_outflow = inStream(outlet.h_outflow);
//Pressure ratio definition
  PR = outlet.p / inlet.p;
// --------------------------------------- //
//            DEBUT PARTIE A COMPLETER     //  
// --------------------------------------- //
  
//Relation entre enthalpie et température pour gaz parfait
  //Tin = ???;
  //Tout = ???;

//Energy balance equation : premier principe système ouvert
  // ??? = ???;
  
//Mass balance equation : conservation masse système ouvert
  // ??? = 0;
  
//Isentropic efficiency definition : se renseigner sur les compresseurs
  //eta_is = ???;
  
//Isentropic temperature as a function of the pressure rate : se renseigner sur les compresseurs
  //Tis = ???;


  
// Caractéristique du compresseur:
N_corr= omega ;//Attention il faut calculer la vitesse corrigée pour interpoler dans la table

table_eta.u1=beta;
table_eta.u2=N_corr;
table_eta.y=eta_is;

table_PR.u1=beta;
table_PR.u2=N_corr;
table_PR.y=PR;

table_qm.u1=beta;
table_qm.u2=N;
table_qm.y=qm_corr ;//Attention le débit corrigé ou réduit dans la table issue du champs compresseur

// --------------------------------------- //
//            FIN   PARTIE A COMPLETER     //  
// --------------------------------------- //

annotation (Documentation(info="<html>
<p> <i>Les trous à compléter sont les mêmes que pour le modèle de compresseur basique.</i> </p>
<p> On utilise un modèle de gaz parfait avec cp=cte, gamma=cte, déjà déclarés dans le package.</p>
<p>
Les tables sont inspirées des courbes du compresseur présentées dans:
<a href=https://uwspace.uwaterloo.ca/bitstream/handle/10012/13858/Kakodkar_Siddharth.pdf>Extensible Modeling of Compressed Air Energy Storage Systems</a>.
</p>
</html>"));
  annotation(
    Icon(graphics = {Polygon(points = {{-80, 80}, {-80, -80}, {80, -40}, {80, 40}, {-80, 80}}), Text(origin = {8, -8}, extent = {{-70, 34}, {70, -34}}, textString = "Compresseur A Tables")}));
end CompressorCombiTable;